@@ -60,7 +60,7 @@ async def get(
 
 
 async def list_(
-    hub, ctx, location: str, filter: str = None, order_by: str = None
+    hub, ctx, location: str, filter_: str = None, order_by: str = None
 ) -> Dict[str, Any]:
     r"""Retrieves key rings under specific location.
 
@@ -68,7 +68,7 @@ async def list_(
         location(str):
             Location ID to be searched for key rings.
 
-        filter(str, Optional):
+        filter_(str, Optional):
             Only include resources that match the filter in the response. For more information, see
             `Sorting and filtering list results`_.
 
@@ -103,7 +103,7 @@ async def list_(
                    - path: gcp.cloudkms.key_ring.list
                    - kwargs:
                          location: projects/project-name/locations/global
-                         filter: NOT name=projects/project-name/locations/global/keyRings/kr-global-test
+                         filter_: NOT name=projects/project-name/locations/global/keyRings/kr-global-test
     """
     result = {
         "comment": [],
@@ -113,7 +113,7 @@ async def list_(
 
     key_rings = (
         await hub.exec.gcp_api.client.cloudkms.projects.locations.key_rings.list(
-            ctx, parent=location, filter=filter, orderBy=order_by
+            ctx, parent=location, filter=filter_, orderBy=order_by
         )
     )
 
