@@ -9,7 +9,7 @@ exec Sub for Google discovery-based Python client library APIs.
 The basic operating model is building Subs as needed to match the nature of a
 call to an exec. For example, a call like:
 
-    hub.exec.gcp_api.client.compute.instances.get(ctx, ...)
+    hub.exec.gcp_api.client.compute.instance.get(ctx, ...)
 
 will work, even though no exec subdirectories exist to match that call path.
 Instead, the API is dynamically discovered and built to match and tie
