@@ -3,5 +3,5 @@
 
 def __init__(hub):
     hub.metadata.gcp.cloudkms.projects.locations.key_rings.PATH = (
-        "projects/{project}/locations/{location}/keyRings/{keyring}"
+        "projects/{project_id}/locations/{location_id}/keyRings/{key_ring_id}"
     )
