@@ -1,6 +1,4 @@
 """State module for managing Cloud Key Management Service crypto keys."""
-import copy
-from copy import deepcopy
 from dataclasses import field
 from dataclasses import make_dataclass
 from typing import Any
@@ -231,7 +229,7 @@ async def present(
             result["comment"] += old_get_ret["comment"]
             return result
 
-        result["old_state"] = copy.deepcopy(copy.copy(old_get_ret["ret"]))
+        result["old_state"] = old_get_ret["ret"]
     elif not get_resource_only_with_resource_id:
         resource_id = hub.tool.gcp.resource_prop_utils.construct_resource_id(
             "cloudkms.projects.locations.key_rings.crypto_keys",
@@ -252,7 +250,7 @@ async def present(
             return result
 
         if old_get_ret["ret"]:
-            result["old_state"] = copy.deepcopy(copy.copy(old_get_ret["ret"]))
+            result["old_state"] = old_get_ret["ret"]
 
     if not result["old_state"]:
         resource_body = {
@@ -294,7 +292,7 @@ async def present(
 
         if ctx["test"]:
             if update_mask or update_primary_version:
-                result["new_state"] = {**deepcopy(result["old_state"]), **resource_body}
+                result["new_state"] = {**result["old_state"], **resource_body}
                 result["comment"].append(
                     hub.tool.gcp.comment_utils.would_update_comment(
                         "gcp.cloudkms.crypto_key", resource_id
@@ -342,7 +340,7 @@ async def present(
                 "location_id": location_id,
                 "key_ring_id": key_ring_id,
                 "crypto_key_id": crypto_key_id,
-                **copy.copy(update_ret["ret"]),
+                **update_ret["ret"],
             }
 
         if update_primary_version:
@@ -366,7 +364,7 @@ async def present(
                 "location_id": location_id,
                 "key_ring_id": key_ring_id,
                 "crypto_key_id": crypto_key_id,
-                "primary": copy.copy(update_version_ret["ret"]["primary"]),
+                "primary": update_version_ret["ret"]["primary"],
             }
 
         if update_mask or update_primary_version:
@@ -430,7 +428,7 @@ async def present(
             "location_id": location_id,
             "key_ring_id": key_ring_id,
             "crypto_key_id": crypto_key_id,
-            **copy.copy(create_ret["ret"]),
+            **create_ret["ret"],
         }
         result["old_state"] = {}
         return result
