@@ -1,6 +1,4 @@
 """State module for managing Cloud Key Management Service crypto keys."""
-import copy
-from copy import deepcopy
 from dataclasses import field
 from dataclasses import make_dataclass
 from typing import Any
@@ -184,7 +182,7 @@ async def present(
             crypto_key_id = els.get("crypto_key_id")
             crypto_key_version_id = els.get("crypto_key_version_id")
 
-        result["old_state"] = copy.deepcopy(copy.copy(old_get_ret["ret"]))
+        result["old_state"] = old_get_ret["ret"]
     elif not get_resource_only_with_resource_id:
         if project_id and location_id and key_ring_id and crypto_key_id:
             if crypto_key_version_id:
@@ -216,7 +214,7 @@ async def present(
             return result
 
         if old_get_ret["ret"]:
-            result["old_state"] = copy.deepcopy(copy.copy(old_get_ret["ret"]))
+            result["old_state"] = old_get_ret["ret"]
 
     resource_body = {
         "state": key_state,
@@ -281,7 +279,7 @@ async def present(
             }
         else:
             result["new_state"] = {
-                **deepcopy(result["old_state"]),
+                **result["old_state"],
                 **{
                     "key_state" if k == "state" else k: v
                     for k, v in resource_body.items()
