@@ -1,6 +1,4 @@
 """State module for managing Cloud Key Management Service import job."""
-import copy
-from copy import deepcopy
 from dataclasses import field
 from dataclasses import make_dataclass
 from typing import Any
@@ -174,7 +172,7 @@ async def present(
             result["comment"] += old_get_ret["comment"]
             return result
 
-        result["old_state"] = copy.deepcopy(copy.copy(old_get_ret["ret"]))
+        result["old_state"] = old_get_ret["ret"]
     elif not get_resource_only_with_resource_id:
         resource_id = hub.tool.gcp.resource_prop_utils.construct_resource_id(
             "cloudkms.projects.locations.key_rings.import_jobs",
@@ -195,7 +193,7 @@ async def present(
             return result
 
         if old_get_ret["ret"]:
-            result["old_state"] = copy.deepcopy(copy.copy(old_get_ret["ret"]))
+            result["old_state"] = old_get_ret["ret"]
 
     if result["old_state"]:
         resource_id = result["old_state"].get("resource_id", None)
@@ -235,7 +233,7 @@ async def present(
                     "gcp.cloudkms.import_job", resource_id
                 )
             )
-            result["new_state"] = deepcopy(result["old_state"])
+            result["new_state"] = result["old_state"]
 
         return result
 
@@ -290,7 +288,7 @@ async def present(
         "location_id": location_id,
         "key_ring_id": key_ring_id,
         "import_job_id": import_job_id,
-        **copy.copy(create_ret["ret"]),
+        **create_ret["ret"],
     }
     return result
 
