@@ -5,6 +5,10 @@ from typing import Any
 from typing import Dict
 from typing import List
 
+from idem_gcp.tool.gcp.utils import global_absent
+
+# prevent commit hook from removing the import
+absent = global_absent
 
 __contracts__ = ["resource"]
 
@@ -413,36 +417,6 @@ async def present(
     return result
 
 
-async def absent(
-    hub,
-    ctx,
-    name: str = None,
-    project: str = None,
-    resource_id: str = None,
-    request_id: str = None,
-) -> Dict[str, Any]:
-    r"""Deletes the resource.
-
-    Args:
-        name(str, Optional):
-            An Idem name of the resource.
-
-        project(str, Optional):
-            Project ID for this request.
-
-        request_id(str, Optional):
-            An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000). Defaults to None.
-
-        resource_id(str, Optional):
-            An identifier of the resource in the provider. Defaults to None.
-
-    Returns:
-        Dict[str, Any]
-    """
-    # the method is handled via the recursive_contracts->call_absent
-    raise NotImplementedError
-
-
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
     r"""Describe the resource in a way that can be recreated/managed with the corresponding "present" function.
 
