@@ -223,9 +223,7 @@ async def present(
 
         result["old_state"] = old_get_ret["ret"]
     elif not get_resource_only_with_resource_id:
-        resource_id = (ctx.get("old_state") or {}).get(
-            "resource_id"
-        ) or hub.tool.gcp.resource_prop_utils.construct_resource_id(
+        resource_id = hub.tool.gcp.resource_prop_utils.construct_resource_id(
             "compute.network", {**locals(), "network": name}
         )
         old_get_ret = await hub.exec.gcp.compute.network.get(
