@@ -44,11 +44,13 @@ async def handle_operation(
         return result
 
     operation = get_ret["ret"]
+    op_ret = {}
     if operation["status"] != "DONE":
         if wait_until_done:
-            operation = await hub.tool.gcp.operation_utils.wait_for_operation(
+            op_ret = await hub.tool.gcp.operation_utils.wait_for_operation(
                 ctx, operation, operation_type
             )
+            operation = op_ret["ret"]
         else:
             result["result"] = False
             new_operation_id = (
@@ -62,9 +64,15 @@ async def handle_operation(
             result["comment"] += get_ret["comment"]
             return result
 
-    if operation.get("error"):
+    op_ret_error_comments = [
+        comment for comment in op_ret.get("comment", []) if "errors" in comment
+    ]
+    if (operation and operation.get("error")) or op_ret_error_comments:
         result["result"] = False
-        result["comment"].append(str(operation.get("error", {})))
+        if operation:
+            result["comment"].append(str(operation.get("error", {})))
+
+        result["comment"] += op_ret_error_comments
         result["rerun_data"] = {"has_error": True}
         return result
 
@@ -100,12 +108,19 @@ async def wait_for_operation(hub, ctx, operation, operation_type: str) -> Dict:
                 break
 
         operation = op_ret["ret"]
-        if operation["status"] == "DONE" or "error" in operation:
+        op_ret_error_comments = [
+            comment for comment in op_ret["comment"] if "errors" in comment
+        ]
+        if (
+            operation["status"] == "DONE"
+            or "error" in operation
+            or op_ret_error_comments
+        ):
             break
 
         await asyncio.sleep(1)
 
-    return operation
+    return op_ret
 
 
 def get_operation_type(hub, operation_id) -> str:
