@@ -172,6 +172,8 @@ class ContractMod(LoadedMod):
         ):
             raw_params["name"] = kwargs["name"]
 
+        raw_params = self._hub.tool.gcp.sanitizers.sanitize_resource_urls(raw_params)
+
         try:
             response = await self._gcp_method(ctx, *args, **raw_params)
             # Is it possible to get None for response. It looks like on error exceptions is thrown. If we are here
@@ -238,6 +240,9 @@ class ContractMod(LoadedMod):
             result["ret"] = self._hub.tool.gcp.resolver.process_response(
                 response, self._resource_type, self._method_name
             )
+            result["ret"] = self._hub.tool.gcp.sanitizers.sanitize_resource_urls(
+                result["ret"]
+            )
         except Exception as e:
             if self._method_name == "get" and isinstance(e, NotFoundError):
                 result["comment"].append(
