@@ -43,7 +43,7 @@ def get_update_properties(
     hub, resource_type: str, convert_to_present: bool = True
 ) -> Set:
     raw_props = set(hub.tool.gcp.RESOURCE_PROPS[resource_type].get("update", {}))
-    if convert_to_present:
+    if raw_props and convert_to_present:
         return hub.tool.gcp.conversion_utils.convert_raw_properties_to_present(
             raw_props
         )
@@ -63,46 +63,30 @@ def get_fields_of_enum_type(
     return raw_props
 
 
-def get_get_properties(hub, resource_type: str, convert_to_present: bool = True) -> Set:
-    raw_props = set(hub.tool.gcp.RESOURCE_PROPS[resource_type].get("get", {}))
-    if convert_to_present:
-        return hub.tool.gcp.conversion_utils.convert_raw_properties_to_present(
-            raw_props
-        )
-    return raw_props
-
-
-def get_delete_properties(
-    hub, resource_type: str, convert_to_present: bool = True
-) -> Set:
-    raw_props = set(hub.tool.gcp.RESOURCE_PROPS[resource_type].get("delete", {}))
-    if convert_to_present:
-        return hub.tool.gcp.conversion_utils.convert_raw_properties_to_present(
-            raw_props
-        )
-    return raw_props
-
-
 def get_non_updatable_properties(hub, resource_type: str) -> Set:
-    raw_nested_non_updatable_properties = hub.tool.gcp.RESOURCE_PROPS[
-        resource_type
-    ].get("nested_non_updatable_properties", [])
+    raw_non_updatable_properties = set()
 
-    non_updatable_properties = set(
-        hub.tool.gcp.conversion_utils.convert_raw_properties_to_present(
-            raw_nested_non_updatable_properties
+    raw_non_updatable_properties.update(
+        hub.tool.gcp.RESOURCE_PROPS[resource_type].get(
+            "nested_non_updatable_properties", []
         )
     )
 
-    non_updatable_properties.update(
+    raw_non_updatable_properties.update(
         hub.tool.gcp.resource_prop_utils.get_create_properties(resource_type)
         - hub.tool.gcp.resource_prop_utils.get_update_properties(resource_type)
     )
 
-    non_updatable_properties.update(
+    raw_non_updatable_properties.update(
         hub.tool.gcp.resource_prop_utils.get_readonly_return_props(resource_type)
     )
 
+    non_updatable_properties = set(
+        hub.tool.gcp.conversion_utils.convert_raw_properties_to_present(
+            raw_non_updatable_properties
+        )
+    )
+
     return non_updatable_properties
 
 
@@ -195,8 +179,9 @@ def get_exclude_keys_from_transformation(
 
     # Create a list, which has lists per each property and have the properties' keys as items
     list_of_properties_key_lists = [
-        list(resource_body[item].keys()) if resource_body.get(item, False) else []
+        list(resource_body[item].keys())
         for item in exclude_properties_from_transformation
+        if resource_body.get(item) and isinstance(resource_body[item], dict)
     ]
 
     # Map the list_of_properties_key_lists to a list containing only the keys to be excluded
